@@ -1,5 +1,6 @@
 import re
-from typing import Any, Iterable, Mapping, Optional, cast
+from math import isfinite
+from typing import Any, Mapping, Optional, cast
 
 from ..language import (
     BooleanValueNode,
@@ -14,7 +15,7 @@ from ..language import (
     StringValueNode,
     ValueNode,
 )
-from ..pyutils import FrozenList, inspect, is_nullish, is_invalid
+from ..pyutils import inspect, is_iterable, Undefined
 from ..type import (
     GraphQLID,
     GraphQLInputType,
@@ -34,20 +35,27 @@ _re_integer_string = re.compile("^-?(?:0|[1-9][0-9]*)$")
 
 
 def ast_from_value(value: Any, type_: GraphQLInputType) -> Optional[ValueNode]:
-    """Produce a GraphQL Value AST given a Python value.
+    """Produce a GraphQL Value AST given a Python object.
+
+    This function will match Python/JSON values to GraphQL AST schema format by using
+    the suggested GraphQLInputType. For example::
+
+        ast_from_value('value', GraphQLString)
 
     A GraphQL type must be provided, which will be used to interpret different Python
     values.
 
-    | JSON Value    | GraphQL Value        |
-    | ------------- | -------------------- |
-    | Object        | Input Object         |
-    | Array         | List                 |
-    | Boolean       | Boolean              |
-    | String        | String / Enum Value  |
-    | Number        | Int / Float          |
-    | Mixed         | Enum Value           |
-    | null          | NullValue            |
+    ================ =======================
+       JSON Value         GraphQL Value
+    ================ =======================
+       Object          Input Object
+       Array           List
+       Boolean         Boolean
+       String          String / Enum Value
+       Number          Int / Float
+       Mixed           Enum Value
+       null            NullValue
+    ================ =======================
 
     """
     if is_non_null_type(type_):
@@ -57,12 +65,12 @@ def ast_from_value(value: Any, type_: GraphQLInputType) -> Optional[ValueNode]:
             return None
         return ast_value
 
-    # only explicit None, not INVALID or NaN
+    # only explicit None, not Undefined or NaN
     if value is None:
         return NullValueNode()
 
-    # INVALID or NaN
-    if is_invalid(value):
+    # undefined
+    if value is Undefined:
         return None
 
     # Convert Python list to GraphQL list. If the GraphQLType is a list, but the value
@@ -70,10 +78,10 @@ def ast_from_value(value: Any, type_: GraphQLInputType) -> Optional[ValueNode]:
     if is_list_type(type_):
         type_ = cast(GraphQLList, type_)
         item_type = type_.of_type
-        if isinstance(value, Iterable) and not isinstance(value, str):
+        if is_iterable(value):
             maybe_value_nodes = (ast_from_value(item, item_type) for item in value)
-            value_nodes = filter(None, maybe_value_nodes)
-            return ListValueNode(values=FrozenList(value_nodes))
+            value_nodes = tuple(node for node in maybe_value_nodes if node)
+            return ListValueNode(values=value_nodes)
         return ast_from_value(value, item_type)
 
     # Populate the fields of the input object by creating ASTs from each value in the
@@ -87,18 +95,18 @@ def ast_from_value(value: Any, type_: GraphQLInputType) -> Optional[ValueNode]:
             for field_name, field in type_.fields.items()
             if field_name in value
         )
-        field_nodes = (
+        field_nodes = tuple(
             ObjectFieldNode(name=NameNode(value=field_name), value=field_value)
             for field_name, field_value in field_items
             if field_value
         )
-        return ObjectValueNode(fields=FrozenList(field_nodes))
+        return ObjectValueNode(fields=field_nodes)
 
     if is_leaf_type(type_):
         # Since value is an internally represented value, it must be serialized to an
         # externally represented value before converting into an AST.
         serialized = type_.serialize(value)  # type: ignore
-        if is_nullish(serialized):
+        if serialized is None or serialized is Undefined:
             return None
 
         # Others serialize based on their corresponding Python scalar types.
@@ -107,9 +115,12 @@ def ast_from_value(value: Any, type_: GraphQLInputType) -> Optional[ValueNode]:
 
         # Python ints and floats correspond nicely to Int and Float values.
         if isinstance(serialized, int):
-            return IntValueNode(value=f"{serialized:d}")
-        if isinstance(serialized, float):
-            return FloatValueNode(value=f"{serialized:g}")
+            return IntValueNode(value=str(serialized))
+        if isinstance(serialized, float) and isfinite(serialized):
+            value = str(serialized)
+            if value.endswith(".0"):
+                value = value[:-2]
+            return FloatValueNode(value=value)
 
         if isinstance(serialized, str):
             # Enum types use Enum literals.
@@ -122,7 +133,7 @@ def ast_from_value(value: Any, type_: GraphQLInputType) -> Optional[ValueNode]:
 
             return StringValueNode(value=serialized)
 
-        raise TypeError(f"Cannot convert value to AST: {inspect(serialized)}")
+        raise TypeError(f"Cannot convert value to AST: {inspect(serialized)}.")
 
     # Not reachable. All possible input types have been considered.
-    raise TypeError(f"Unexpected input type: '{inspect(type_)}'.")  # pragma: no cover
+    raise TypeError(f"Unexpected input type: {inspect(type_)}.")
