@@ -1,9 +1,10 @@
-from typing import Any
+from typing import cast, Any, Awaitable
 
 from pytest import mark
 
 from graphql.execution import execute, execute_sync, ExecutionResult
 from graphql.language import parse
+from graphql.pyutils import is_awaitable
 from graphql.utilities import build_schema
 
 
@@ -25,13 +26,14 @@ def describe_execute_accepts_any_iterable_as_list_value():
         )
 
     def accepts_a_set_as_a_list_value():
-        # We need to use a dict instead of a set,
-        # since sets are not ordered in Python.
-        list_field = dict.fromkeys(["apple", "banana", "coconut"])
-        assert _complete(list_field) == (
-            {"listField": ["apple", "banana", "coconut"]},
-            None,
-        )
+        # Note that sets are not ordered in Python.
+        list_field = {"apple", "banana", "coconut"}
+        result = _complete(list_field)
+        assert result.errors is None
+        assert isinstance(result.data, dict)
+        assert list(result.data) == ["listField"]
+        assert isinstance(result.data["listField"], list)
+        assert set(result.data["listField"]) == list_field
 
     def accepts_a_generator_as_a_list_value():
         def list_field():
@@ -44,6 +46,24 @@ def describe_execute_accepts_any_iterable_as_list_value():
             None,
         )
 
+    def accepts_a_custom_iterable_as_a_list_value():
+        class ListField:
+            def __iter__(self):
+                self.last = "hello"
+                return self
+
+            def __next__(self):
+                last = self.last
+                if last == "stop":
+                    raise StopIteration
+                self.last = "world" if last == "hello" else "stop"
+                return last
+
+        assert _complete(ListField()) == (
+            {"listField": ["hello", "world"]},
+            None,
+        )
+
     def accepts_function_arguments_as_a_list_value():
         def get_args(*args):
             return args  # actually just a tuple, nothing special in Python
@@ -53,6 +73,19 @@ def describe_execute_accepts_any_iterable_as_list_value():
             None,
         )
 
+    def does_not_accept_a_dict_as_a_list_value():
+        assert _complete({1: "one", 2: "two"}) == (
+            {"listField": None},
+            [
+                {
+                    "message": "Expected Iterable,"
+                    " but did not find one for field 'Query.listField'.",
+                    "locations": [(1, 3)],
+                    "path": ["listField"],
+                }
+            ],
+        )
+
     def does_not_accept_iterable_string_literal_as_a_list_value():
         assert _complete("Singular") == (
             {"listField": None},
@@ -181,3 +214,46 @@ def describe_execute_handles_list_nullability():
             None,
             errors,
         )
+
+
+def describe_experimental_execute_accepts_async_iterables_as_list_value():
+    async def _complete(list_field):
+        result = execute(
+            build_schema("type Query { listField: [String] }"),
+            parse("{ listField }"),
+            Data(list_field),
+        )
+        assert is_awaitable(result)
+        result = cast(Awaitable, result)
+        return await result
+
+    @mark.asyncio
+    async def accepts_an_async_generator_as_a_list_value():
+        async def list_field():
+            yield "one"
+            yield 2
+            yield True
+
+        assert await _complete(list_field()) == (
+            {"listField": ["one", "2", "true"]},
+            None,
+        )
+
+    @mark.asyncio
+    async def accepts_a_custom_async_iterable_as_a_list_value():
+        class ListField:
+            def __aiter__(self):
+                self.last = "hello"
+                return self
+
+            async def __anext__(self):
+                last = self.last
+                if last == "stop":
+                    raise StopAsyncIteration
+                self.last = "world" if last == "hello" else "stop"
+                return last
+
+        assert await _complete(ListField()) == (
+            {"listField": ["hello", "world"]},
+            None,
+        )
