@@ -1,10 +1,11 @@
 import re
-from inspect import isawaitable
+from typing import Any, Awaitable, cast
 
-from pytest import mark  # type: ignore
+from pytest import mark
 
-from graphql.execution import execute
+from graphql.execution import execute, execute_sync, ExecutionResult
 from graphql.language import parse
+from graphql.pyutils import AwaitableOrValue
 from graphql.type import (
     GraphQLArgument,
     GraphQLField,
@@ -95,22 +96,22 @@ schema = build_schema(
 )
 
 
-def execute_query(query, root_value):
+def execute_query(query: str, root_value: Any) -> AwaitableOrValue[ExecutionResult]:
     return execute(schema=schema, document=parse(query), root_value=root_value)
 
 
 # avoids also doing any nests
-def patch(data):
+def patch(data: str) -> str:
     return re.sub(
         r"\bsyncNonNull\b", "promiseNonNull", re.sub(r"\bsync\b", "promise", data)
     )
 
 
-async def execute_sync_and_async(query, root_value):
-    sync_result = execute_query(query, root_value)
-    if isawaitable(sync_result):
-        sync_result = await sync_result
-    async_result = await execute_query(patch(query), root_value)
+async def execute_sync_and_async(query: str, root_value: Any) -> ExecutionResult:
+    sync_result = execute_sync(schema, parse(query), root_value)
+    async_result = await cast(
+        Awaitable[ExecutionResult], execute(schema, parse(patch(query)), root_value)
+    )
 
     assert repr(async_result) == patch(repr(sync_result))
     return sync_result
@@ -143,7 +144,7 @@ def describe_execute_handles_non_nullable_types():
                 ],
             )
 
-    def describe_nulls_an_immediate_object_that_contains_a_non_null_field():
+    def describe_nulls_a_returned_object_that_contains_a_non_null_field():
 
         query = """
             {
@@ -154,7 +155,7 @@ def describe_execute_handles_non_nullable_types():
             """
 
         @mark.asyncio
-        async def returns_null():
+        async def that_returns_null():
             result = await execute_sync_and_async(query, NullingData())
             assert result == (
                 {"syncNest": None},
@@ -169,7 +170,7 @@ def describe_execute_handles_non_nullable_types():
             )
 
         @mark.asyncio
-        async def throws():
+        async def that_throws():
             result = await execute_sync_and_async(query, ThrowingData())
             assert result == (
                 {"syncNest": None},
@@ -182,44 +183,6 @@ def describe_execute_handles_non_nullable_types():
                 ],
             )
 
-    def describe_nulls_a_promised_object_that_contains_a_non_null_field():
-        query = """
-            {
-              promiseNest {
-                syncNonNull,
-              }
-            }
-            """
-
-        @mark.asyncio
-        async def returns_null():
-            result = await execute_sync_and_async(query, NullingData())
-            assert result == (
-                {"promiseNest": None},
-                [
-                    {
-                        "message": "Cannot return null for non-nullable field"
-                        " DataType.syncNonNull.",
-                        "path": ["promiseNest", "syncNonNull"],
-                        "locations": [(4, 17)],
-                    }
-                ],
-            )
-
-        @mark.asyncio
-        async def throws():
-            result = await execute_sync_and_async(query, ThrowingData())
-            assert result == (
-                {"promiseNest": None},
-                [
-                    {
-                        "message": str(sync_non_null_error),
-                        "path": ["promiseNest", "syncNonNull"],
-                        "locations": [(4, 17)],
-                    }
-                ],
-            )
-
     def describe_nulls_a_complex_tree_of_nullable_fields_each():
         query = """
             {
@@ -254,12 +217,16 @@ def describe_execute_handles_non_nullable_types():
 
         @mark.asyncio
         async def returns_null():
-            result = await execute_query(query, NullingData())
+            result = await cast(
+                Awaitable[ExecutionResult], execute_query(query, NullingData())
+            )
             assert result == (data, None)
 
         @mark.asyncio
         async def throws():
-            result = await execute_query(query, ThrowingData())
+            result = await cast(
+                Awaitable[ExecutionResult], execute_query(query, ThrowingData())
+            )
             assert result == (
                 data,
                 [
@@ -384,7 +351,9 @@ def describe_execute_handles_non_nullable_types():
 
         @mark.asyncio
         async def returns_null():
-            result = await execute_query(query, NullingData())
+            result = await cast(
+                Awaitable[ExecutionResult], execute_query(query, NullingData())
+            )
             assert result == (
                 data,
                 [
@@ -445,7 +414,9 @@ def describe_execute_handles_non_nullable_types():
 
         @mark.asyncio
         async def throws():
-            result = await execute_query(query, ThrowingData())
+            result = await cast(
+                Awaitable[ExecutionResult], execute_query(query, ThrowingData())
+            )
             assert result == (
                 data,
                 [
@@ -558,7 +529,7 @@ def describe_execute_handles_non_nullable_types():
         )
 
         def succeeds_when_passed_non_null_literal_value():
-            result = execute(
+            result = execute_sync(
                 schema_with_non_null_arg,
                 parse(
                     """
@@ -572,7 +543,24 @@ def describe_execute_handles_non_nullable_types():
             assert result == ({"withNonNullArg": "Passed: literal value"}, None)
 
         def succeeds_when_passed_non_null_variable_value():
-            result = execute(
+            result = execute_sync(
+                schema_with_non_null_arg,
+                parse(
+                    """
+                    query ($testVar: String!) {
+                      withNonNullArg (cannotBeNull: $testVar)
+                    }
+                    """
+                ),
+                variable_values={
+                    "testVar": "variable value",
+                },
+            )
+
+            assert result == ({"withNonNullArg": "Passed: variable value"}, None)
+
+        def succeeds_when_missing_variable_has_default_value():
+            result = execute_sync(
                 schema_with_non_null_arg,
                 parse(
                     """
@@ -581,8 +569,8 @@ def describe_execute_handles_non_nullable_types():
                     }
                     """
                 ),
-                variable_values={},
-            )  # intentionally missing variable
+                variable_values={},  # intentionally missing variable
+            )
 
             assert result == ({"withNonNullArg": "Passed: default value"}, None)
 
@@ -590,7 +578,7 @@ def describe_execute_handles_non_nullable_types():
             # Note: validation should identify this issue first
             # (missing args rule) however execution should still
             # protect against this.
-            result = execute(
+            result = execute_sync(
                 schema_with_non_null_arg,
                 parse(
                     """
@@ -617,7 +605,7 @@ def describe_execute_handles_non_nullable_types():
             # Note: validation should identify this issue first
             # (values of correct type rule) however execution
             # should still protect against this.
-            result = execute(
+            result = execute_sync(
                 schema_with_non_null_arg,
                 parse(
                     """
@@ -644,7 +632,7 @@ def describe_execute_handles_non_nullable_types():
             # Note: validation should identify this issue first
             # (variables in allowed position rule) however execution
             # should still protect against this.
-            result = execute(
+            result = execute_sync(
                 schema_with_non_null_arg,
                 parse(
                     """
@@ -671,7 +659,7 @@ def describe_execute_handles_non_nullable_types():
             )
 
         def field_error_when_non_null_arg_provided_explicit_null_variable():
-            result = execute(
+            result = execute_sync(
                 schema_with_non_null_arg,
                 parse(
                     """
