@@ -1,7 +1,7 @@
 from contextlib import contextmanager
 from typing import cast
 
-from pytest import raises  # type: ignore
+from pytest import raises
 
 from graphql import graphql_sync
 from graphql.type import (
@@ -21,11 +21,13 @@ from graphql.pyutils import (
     register_description,
     unregister_description,
 )
-from graphql.utilities import get_introspection_query
+from graphql.utilities import get_introspection_query, print_schema
+
+from ..utils import dedent
 
 
 class LazyString:
-    def __init__(self, text: object):
+    def __init__(self, text: object) -> None:
         self.text = text
 
     def __str__(self) -> str:
@@ -107,7 +109,7 @@ def describe_description():
             named_type = GraphQLNamedType(name="Foo", description="not lazy")
             assert named_type.name == "Foo"
             assert named_type.description == "not lazy"
-            with raises(TypeError, match="The name must be a string\\."):
+            with raises(TypeError, match="Expected name to be a string\\."):
                 GraphQLNamedType(name=lazy_string)
             with raises(TypeError, match="The description must be a string\\."):
                 GraphQLNamedType(name="Foo", description=lazy_string)
@@ -115,7 +117,7 @@ def describe_description():
                 named_type = GraphQLNamedType(name="Foo", description=lazy_string)
                 assert named_type.description is lazy_string
                 assert str(named_type.description).endswith("lazy?")
-                with raises(TypeError, match="The name must be a string\\."):
+                with raises(TypeError, match="Expected name to be a string\\."):
                     GraphQLNamedType(name=lazy_string)
 
         def graphql_field():
@@ -185,7 +187,7 @@ def describe_description():
             directive = GraphQLDirective("Foo", [], description="not lazy")
             assert directive.name == "Foo"
             assert directive.description == "not lazy"
-            with raises(TypeError, match="The directive name must be a string\\."):
+            with raises(TypeError, match="Expected name to be a string\\."):
                 GraphQLDirective(lazy_string, [])
             with raises(TypeError, match="Foo description must be a string\\."):
                 GraphQLDirective("Foo", [], description=lazy_string)
@@ -193,10 +195,10 @@ def describe_description():
                 directive = GraphQLDirective("Foo", [], description=lazy_string)
                 assert directive.description is lazy_string
                 assert str(directive.description).endswith("lazy?")
-                with raises(TypeError, match="The directive name must be a string\\."):
+                with raises(TypeError, match="Expected name to be a string\\."):
                     GraphQLDirective(lazy_string, [])
 
-    def introspection():
+    def handels_introspection():
         class Lazy:
             def __init__(self, text: str):
                 self.text = text
@@ -231,3 +233,38 @@ def describe_description():
         assert introspected_field["name"] == "lazyField"
         assert introspected_field["description"] == "a lazy description"
         assert introspected_field["deprecationReason"] == "a lazy reason"
+
+    def handles_printing():
+        class Lazy:
+            def __init__(self, text: str):
+                self.text = text
+                self.evaluated = False
+
+            def __str__(self) -> str:
+                self.evaluated = True
+                return self.text
+
+        description = Lazy("a lazy description")
+        deprecation_reason = Lazy("a lazy reason")
+
+        with registered(Lazy):
+            field = GraphQLField(
+                GraphQLString,
+                description=cast(str, description),
+                deprecation_reason=cast(str, deprecation_reason),
+            )
+
+        schema = GraphQLSchema(GraphQLObjectType("Query", {"lazyField": field}))
+
+        assert not description.evaluated
+        assert not deprecation_reason.evaluated
+        assert print_schema(schema) == dedent(
+            '''
+            type Query {
+              """a lazy description"""
+              lazyField: String @deprecated(reason: "a lazy reason")
+            }
+            '''
+        )
+        assert description.evaluated
+        assert deprecation_reason.evaluated
