@@ -10,6 +10,11 @@ from enum import Enum
 from inspect import isawaitable
 from typing import Any, Dict, List, NamedTuple, Optional
 
+try:
+    from asyncio import create_task
+except ImportError:  # Python < 3.7
+    create_task = None  # type: ignore
+
 from pytest import fixture, mark
 
 from graphql import (
@@ -31,7 +36,7 @@ from graphql import (
 )
 
 from graphql.pyutils import SimplePubSub, SimplePubSubIterator
-from graphql.subscription.map_async_iterator import MapAsyncIterator
+from graphql.execution.map_async_iterator import MapAsyncIterator
 
 
 class User(NamedTuple):
@@ -159,7 +164,7 @@ async def subscribe_user(_root, info, id=None):
     """Subscribe to mutations of a specific user object or all user objects"""
     async_iterator = info.context["registry"].event_iterator(id)
     async for event in async_iterator:
-        yield await event if isawaitable(event) else event
+        yield await event if isawaitable(event) else event  # pragma: no cover exit
 
 
 # noinspection PyShadowingBuiltins,PyUnusedLocal
@@ -493,20 +498,22 @@ def describe_subscription():
             )
 
         async def receive_one():
-            async for result in subscription_one:  # type: ignore
+            async for result in subscription_one:  # type: ignore # pragma: no cover
                 received_one.append(result)
-                if len(received_one) == 3:
+                if len(received_one) == 3:  # pragma: no cover else
                     break
 
         async def receive_all():
-            async for result in subscription_all:  # type: ignore
+            async for result in subscription_all:  # type: ignore # pragma: no cover
                 received_all.append(result)
-                if len(received_all) == 6:
+                if len(received_all) == 6:  # pragma: no cover else
                     break
 
-        done, pending = await wait(
-            [mutate_users(), receive_one(), receive_all()], timeout=1
-        )
+        tasks = [
+            create_task(task()) if create_task else task()
+            for task in (mutate_users, receive_one, receive_all)
+        ]
+        done, pending = await wait(tasks, timeout=1)
         assert not pending
 
         expected_data: List[Dict[str, Any]] = [
