@@ -9,7 +9,7 @@ from graphql.version import (
     version_info_js,
 )
 
-_re_version = re.compile(r"(\d+)\.(\d+)\.(\d+)(?:(a|b|c)(\d+))?$")
+_re_version = re.compile(r"(\d+)\.(\d+)\.(\d+)(?:(a|b|r?c)(\d+))?$")
 
 
 def describe_version():
@@ -53,6 +53,8 @@ def describe_version():
             assert str(v) == "1.2.3"
             v = VersionInfo(1, 2, 3, "alpha", 4)
             assert str(v) == "1.2.3a4"
+            v = VersionInfo(1, 2, 3, "candidate", 4)
+            assert str(v) == "1.2.3rc4"
 
     def describe_graphql_core_version():
         def base_package_has_correct_version():
@@ -74,10 +76,10 @@ def describe_version():
             assert version_info.major == int(groups[0])
             assert version_info.minor == int(groups[1])
             assert version_info.micro == int(groups[2])
-            if groups[3] is None:
+            if groups[3] is None:  # pragma: no cover
                 assert groups[4] is None
-            else:
-                assert version_info.releaselevel[:1] == groups[3]
+            else:  # pragma: no cover
+                assert version_info.releaselevel[:1] == groups[3].lstrip("r")
                 assert version_info.serial == int(groups[4])
 
     def describe_graphql_js_version():
@@ -100,8 +102,8 @@ def describe_version():
             assert version_info_js.major == int(groups[0])
             assert version_info_js.minor == int(groups[1])
             assert version_info_js.micro == int(groups[2])
-            if groups[3] is None:
+            if groups[3] is None:  # pragma: no cover
                 assert groups[4] is None
-            else:
-                assert version_info_js.releaselevel[:1] == groups[3]
+            else:  # pragma: no cover
+                assert version_info_js.releaselevel[:1] == groups[3].lstrip("r")
                 assert version_info_js.serial == int(groups[4])
