@@ -1,10 +1,10 @@
 from operator import attrgetter
 from typing import Any, List, Union
 
-from pytest import mark, raises  # type: ignore
+from pytest import mark, raises
 
 from graphql.language import parse, DirectiveLocation
-from graphql.pyutils import dedent, inspect
+from graphql.pyutils import inspect
 from graphql.type import (
     assert_directive,
     assert_enum_type,
@@ -20,7 +20,6 @@ from graphql.type import (
     GraphQLArgument,
     GraphQLDirective,
     GraphQLEnumType,
-    GraphQLEnumValue,
     GraphQLField,
     GraphQLInputField,
     GraphQLInputType,
@@ -38,6 +37,7 @@ from graphql.type import (
 )
 from graphql.utilities import build_schema, extend_schema
 
+from ..utils import dedent
 
 SomeSchema = build_schema(
     """
@@ -114,8 +114,7 @@ get_name = attrgetter("__class__.__name__")
 
 def schema_with_field_type(type_):
     return GraphQLSchema(
-        query=GraphQLObjectType(name="Query", fields={"f": GraphQLField(type_)}),
-        types=[type_],
+        query=GraphQLObjectType(name="Query", fields={"f": GraphQLField(type_)})
     )
 
 
@@ -494,14 +493,12 @@ def describe_type_system_objects_must_have_fields():
 
     def rejects_an_object_type_with_incorrectly_named_fields():
         schema = schema_with_field_type(
-            GraphQLObjectType(
-                "SomeObject", {"bad-name-with-dashes": GraphQLField(GraphQLString)}
-            )
+            GraphQLObjectType("SomeObject", {"__badName": GraphQLField(GraphQLString)})
         )
         msg = validate_schema(schema)[0].message
         assert msg == (
-            "Names must match /^[_a-zA-Z][_a-zA-Z0-9]*$/"
-            " but 'bad-name-with-dashes' does not."
+            "Name '__badName' must not begin with '__',"
+            " which is reserved by GraphQL introspection."
         )
 
 
@@ -519,21 +516,23 @@ def describe_type_system_field_args_must_be_properly_named():
         )
         assert validate_schema(schema) == []
 
-    def reject_field_args_with_invalid_names():
-        QueryType = GraphQLObjectType(
-            "SomeObject",
-            {
-                "badField": GraphQLField(
-                    GraphQLString,
-                    args={"bad-name-with-dashes": GraphQLArgument(GraphQLString)},
-                )
-            },
+    def rejects_field_args_with_invalid_names():
+        schema = schema_with_field_type(
+            GraphQLObjectType(
+                "SomeObject",
+                {
+                    "badField": GraphQLField(
+                        GraphQLString,
+                        args={"__badName": GraphQLArgument(GraphQLString)},
+                    )
+                },
+            )
         )
-        schema = GraphQLSchema(QueryType)
+
         msg = validate_schema(schema)[0].message
         assert msg == (
-            "Names must match /^[_a-zA-Z][_a-zA-Z0-9]*$/"
-            " but 'bad-name-with-dashes' does not."
+            "Name '__badName' must not begin with '__',"
+            " which is reserved by GraphQL introspection."
         )
 
 
@@ -687,10 +686,14 @@ def describe_type_system_union_types_must_be_valid():
         )
         schema = extend_schema(schema, parse("extend union BadUnion = TypeB"))
         bad_union: Any = schema.get_type("BadUnion")
-        assert bad_union.types[1].name == "TypeA"
-        bad_union.types[1] = GraphQLString
-        assert bad_union.types[3].name == "TypeB"
-        bad_union.types[3] = GraphQLInt
+        types = bad_union.types
+        assert isinstance(types, tuple)
+        types = list(types)
+        assert types[1].name == "TypeA"
+        types[1] = GraphQLString
+        assert types[3].name == "TypeB"
+        types[3] = GraphQLInt
+        bad_union.types = tuple(types)
         bad_union.ast_node.types[1].name.value = "String"
         bad_union.extension_ast_nodes[0].types[0].name.value = "Int"
         assert validate_schema(schema) == [
@@ -938,6 +941,28 @@ def describe_type_system_input_objects_must_have_fields():
             },
         ]
 
+    def rejects_an_input_object_type_with_required_arguments_that_is_deprecated():
+        schema = build_schema(
+            """
+            type Query {
+              field(arg: SomeInputObject): String
+            }
+
+            input SomeInputObject {
+              badField: String! @deprecated
+              optionalField: String @deprecated
+              anotherOptionalField: String! = "" @deprecated
+            }
+            """
+        )
+        assert validate_schema(schema) == [
+            {
+                "message": "Required input field SomeInputObject.badField"
+                " cannot be deprecated.",
+                "locations": [(7, 33), (7, 25)],
+            }
+        ]
+
 
 def describe_type_system_enum_types_must_be_well_defined():
     def rejects_an_enum_type_without_values():
@@ -970,54 +995,30 @@ def describe_type_system_enum_types_must_be_well_defined():
         ]
 
     def rejects_an_enum_type_with_incorrectly_named_values():
-        def schema_with_enum(name):
-            return schema_with_field_type(
-                GraphQLEnumType("SomeEnum", {name: GraphQLEnumValue(1)})
-            )
-
-        schema1 = schema_with_enum("#value")
-        msg = validate_schema(schema1)[0].message
-        assert msg == (
-            "Names must match /^[_a-zA-Z][_a-zA-Z0-9]*$/ but '#value' does not."
+        schema = schema_with_field_type(
+            GraphQLEnumType("SomeEnum", values={"__badName": {}})
         )
 
-        schema2 = schema_with_enum("1value")
-        msg = validate_schema(schema2)[0].message
-        assert msg == (
-            "Names must match /^[_a-zA-Z][_a-zA-Z0-9]*$/ but '1value' does not."
-        )
-
-        schema3 = schema_with_enum("KEBAB-CASE")
-        msg = validate_schema(schema3)[0].message
-        assert msg == (
-            "Names must match /^[_a-zA-Z][_a-zA-Z0-9]*$/ but 'KEBAB-CASE' does not."
-        )
-
-        schema4 = schema_with_enum("true")
-        msg = validate_schema(schema4)[0].message
-        assert msg == "Enum type SomeEnum cannot include value: true."
-
-        schema5 = schema_with_enum("false")
-        msg = validate_schema(schema5)[0].message
-        assert msg == "Enum type SomeEnum cannot include value: false."
-
-        schema6 = schema_with_enum("null")
-        msg = validate_schema(schema6)[0].message
-        assert msg == "Enum type SomeEnum cannot include value: null."
+        assert validate_schema(schema) == [
+            {
+                "message": "Name '__badName' must not begin with '__',"
+                " which is reserved by GraphQL introspection."
+            }
+        ]
 
 
 def describe_type_system_object_fields_must_have_output_types():
-    def _schema_with_object_field_of_type(field_type: GraphQLOutputType):
-        if is_output_type(field_type):
-            field = GraphQLField(field_type)
+    def _schema_with_object_field(type_: GraphQLOutputType) -> GraphQLSchema:
+        if is_output_type(type_):
+            field = GraphQLField(type_)
         else:
             # invalid field cannot be built with Python directly
             with raises(TypeError) as exc_info:
-                GraphQLField(field_type)
+                GraphQLField(type_)
             assert str(exc_info.value) == "Field type must be an output type."
             # therefore we need to monkey-patch a valid field
             field = GraphQLField(GraphQLString)
-            field.type = field_type
+            field.type = type_
         bad_object_type = GraphQLObjectType("BadObject", {"badField": field})
         return GraphQLSchema(
             GraphQLObjectType("Query", {"f": GraphQLField(bad_object_type)}),
@@ -1026,12 +1027,12 @@ def describe_type_system_object_fields_must_have_output_types():
 
     @mark.parametrize("type_", output_types, ids=get_name)
     def accepts_an_output_type_as_an_object_field_type(type_):
-        schema = _schema_with_object_field_of_type(type_)
+        schema = _schema_with_object_field(type_)
         assert validate_schema(schema) == []
 
     def rejects_an_empty_object_field_type():
         # noinspection PyTypeChecker
-        schema = _schema_with_object_field_of_type(None)  # type: ignore
+        schema = _schema_with_object_field(None)  # type: ignore
         assert validate_schema(schema) == [
             {
                 "message": "The type of BadObject.badField must be Output Type"
@@ -1041,7 +1042,7 @@ def describe_type_system_object_fields_must_have_output_types():
 
     @mark.parametrize("type_", not_output_types, ids=get_name)
     def rejects_a_non_output_type_as_an_object_field_type(type_):
-        schema = _schema_with_object_field_of_type(type_)
+        schema = _schema_with_object_field(type_)
         assert validate_schema(schema) == [
             {
                 "message": "The type of BadObject.badField must be Output Type"
@@ -1051,7 +1052,7 @@ def describe_type_system_object_fields_must_have_output_types():
 
     @mark.parametrize("type_", not_graphql_types, ids=get_name)
     def rejects_a_non_type_value_as_an_object_field_type(type_):
-        schema = _schema_with_object_field_of_type(type_)
+        schema = _schema_with_object_field(type_)
         assert validate_schema(schema) == [
             {
                 "message": "The type of BadObject.badField must be Output Type"
@@ -1101,12 +1102,13 @@ def describe_type_system_object_fields_must_have_output_types():
 
 
 def describe_type_system_objects_can_only_implement_unique_interfaces():
-    def rejects_an_object_implementing_a_non_type_values():
+    def rejects_an_object_implementing_a_non_type_value():
         query_type = GraphQLObjectType(
-            "BadObject", {"f": GraphQLField(GraphQLString)}, interfaces=[]
+            "BadObject",
+            {"f": GraphQLField(GraphQLString)},
         )
         # noinspection PyTypeChecker
-        query_type.interfaces.append(None)
+        query_type.interfaces = (None,)
         schema = GraphQLSchema(query_type)
 
         assert validate_schema(schema) == [
@@ -1324,20 +1326,24 @@ def describe_type_system_interface_extensions_should_be_valid():
 
 
 def describe_type_system_interface_fields_must_have_output_types():
-    def _schema_with_interface_field_of_type(field_type: GraphQLOutputType):
-        if is_output_type(field_type):
-            field = GraphQLField(field_type)
+    def _schema_with_interface_field(type_: GraphQLOutputType) -> GraphQLSchema:
+        if is_output_type(type_):
+            field = GraphQLField(type_)
         else:
             # invalid field cannot be built with Python directly
             with raises(TypeError) as exc_info:
-                GraphQLField(field_type)
+                GraphQLField(type_)
             assert str(exc_info.value) == "Field type must be an output type."
             # therefore we need to monkey-patch a valid field
             field = GraphQLField(GraphQLString)
-            field.type = field_type
-        bad_interface_type = GraphQLInterfaceType("BadInterface", {"badField": field})
+            field.type = type_
+        fields = {"badField": field}
+
+        bad_interface_type = GraphQLInterfaceType("BadInterface", fields)
         bad_implementing_type = GraphQLObjectType(
-            "BadImplementing", {"badField": field}, interfaces=[bad_interface_type],
+            "BadImplementing",
+            fields,
+            interfaces=[bad_interface_type],
         )
         return GraphQLSchema(
             GraphQLObjectType("Query", {"f": GraphQLField(bad_interface_type)}),
@@ -1346,12 +1352,12 @@ def describe_type_system_interface_fields_must_have_output_types():
 
     @mark.parametrize("type_", output_types, ids=get_name)
     def accepts_an_output_type_as_an_interface_field_type(type_):
-        schema = _schema_with_interface_field_of_type(type_)
+        schema = _schema_with_interface_field(type_)
         assert validate_schema(schema) == []
 
     def rejects_an_empty_interface_field_type():
         # noinspection PyTypeChecker
-        schema = _schema_with_interface_field_of_type(None)  # type: ignore
+        schema = _schema_with_interface_field(None)  # type: ignore
         assert validate_schema(schema) == [
             {
                 "message": "The type of BadImplementing.badField must be Output Type"
@@ -1365,7 +1371,7 @@ def describe_type_system_interface_fields_must_have_output_types():
 
     @mark.parametrize("type_", not_output_types, ids=get_name)
     def rejects_a_non_output_type_as_an_interface_field_type(type_):
-        schema = _schema_with_interface_field_of_type(type_)
+        schema = _schema_with_interface_field(type_)
         assert validate_schema(schema) == [
             {
                 "message": "The type of BadImplementing.badField must be Output Type"
@@ -1379,7 +1385,7 @@ def describe_type_system_interface_fields_must_have_output_types():
 
     @mark.parametrize("type_", not_graphql_types, ids=get_name)
     def rejects_a_non_type_value_as_an_interface_field_type(type_):
-        schema = _schema_with_interface_field_of_type(type_)
+        schema = _schema_with_interface_field(type_)
         assert validate_schema(schema) == [
             {
                 "message": "The type of BadImplementing.badField must be Output Type"
@@ -1473,38 +1479,41 @@ def describe_type_system_interface_fields_must_have_output_types():
 
 
 def describe_type_system_arguments_must_have_input_types():
-    def _schema_with_arg_of_type(arg_type: GraphQLInputType):
-        if is_input_type(arg_type):
-            argument = GraphQLArgument(arg_type)
+    def _schema_with_arg(type_: GraphQLInputType) -> GraphQLSchema:
+        if is_input_type(type_):
+            argument = GraphQLArgument(type_)
         else:
             # invalid argument cannot be built with Python directly
             with raises(TypeError) as exc_info:
-                GraphQLArgument(arg_type)
+                GraphQLArgument(type_)
             assert str(exc_info.value) == "Argument type must be a GraphQL input type."
             # therefore we need to monkey-patch a valid argument
             argument = GraphQLArgument(GraphQLString)
-            argument.type = arg_type
+            argument.type = type_
+        args = {"badArg": argument}
         bad_object_type = GraphQLObjectType(
             "BadObject",
-            {"badField": GraphQLField(GraphQLString, args={"badArg": argument})},
+            {"badField": GraphQLField(GraphQLString, args)},
         )
         return GraphQLSchema(
             GraphQLObjectType("Query", {"f": GraphQLField(bad_object_type)}),
             directives=[
                 GraphQLDirective(
-                    "BadDirective", [DirectiveLocation.QUERY], {"badArg": argument},
+                    "BadDirective",
+                    [DirectiveLocation.QUERY],
+                    args,
                 )
             ],
         )
 
     @mark.parametrize("type_", input_types, ids=get_name)
     def accepts_an_input_type_as_a_field_arg_type(type_):
-        schema = _schema_with_arg_of_type(type_)
+        schema = _schema_with_arg(type_)
         assert validate_schema(schema) == []
 
     def rejects_an_empty_field_arg_type():
         # noinspection PyTypeChecker
-        schema = _schema_with_arg_of_type(None)  # type: ignore
+        schema = _schema_with_arg(None)  # type: ignore
         assert validate_schema(schema) == [
             {
                 "message": "The type of @BadDirective(badArg:) must be Input Type"
@@ -1518,7 +1527,7 @@ def describe_type_system_arguments_must_have_input_types():
 
     @mark.parametrize("type_", not_input_types, ids=get_name)
     def rejects_a_non_input_type_as_a_field_arg_type(type_):
-        schema = _schema_with_arg_of_type(type_)
+        schema = _schema_with_arg(type_)
         assert validate_schema(schema) == [
             {
                 "message": "The type of @BadDirective(badArg:) must be Input Type"
@@ -1532,7 +1541,7 @@ def describe_type_system_arguments_must_have_input_types():
 
     @mark.parametrize("type_", not_graphql_types, ids=get_name)
     def rejects_a_non_type_value_as_a_field_arg_type(type_):
-        schema = _schema_with_arg_of_type(type_)
+        schema = _schema_with_arg(type_)
         assert validate_schema(schema) == [
             {
                 "message": "The type of @BadDirective(badArg:) must be Input Type"
@@ -1545,6 +1554,37 @@ def describe_type_system_arguments_must_have_input_types():
             {"message": f"Expected GraphQL named type but got: {inspect(type_)}."},
         ]
 
+    def rejects_a_required_argument_that_is_deprecated():
+        schema = build_schema(
+            """
+            directive @BadDirective(
+              badArg: String! @deprecated
+              optionalArg: String @deprecated
+              anotherOptionalArg: String! = "" @deprecated
+            ) on FIELD
+
+            type Query {
+              test(
+                badArg: String! @deprecated
+                optionalArg: String @deprecated
+                anotherOptionalArg: String! = "" @deprecated
+              ): String
+            }
+            """
+        )
+        assert validate_schema(schema) == [
+            {
+                "message": "Required argument @BadDirective(badArg:)"
+                " cannot be deprecated.",
+                "locations": [(3, 31), (3, 23)],
+            },
+            {
+                "message": "Required argument Query.test(badArg:)"
+                " cannot be deprecated.",
+                "locations": [(10, 33), (10, 25)],
+            },
+        ]
+
     def rejects_a_non_input_type_as_a_field_arg_with_locations():
         # invalid schema cannot be built with Python
         with raises(TypeError) as exc_info:
@@ -1587,19 +1627,19 @@ def describe_type_system_arguments_must_have_input_types():
 
 
 def describe_type_system_input_object_fields_must_have_input_types():
-    def _schema_with_input_field_of_type(input_field_type: GraphQLInputType):
-        if is_input_type(input_field_type):
-            input_field = GraphQLInputField(input_field_type)
+    def _schema_with_input_field(type_: GraphQLInputType) -> GraphQLSchema:
+        if is_input_type(type_):
+            input_field = GraphQLInputField(type_)
         else:
             # invalid input field cannot be built with Python directly
             with raises(TypeError) as exc_info:
-                GraphQLInputField(input_field_type)
+                GraphQLInputField(type_)
             assert str(exc_info.value) == (
                 "Input field type must be a GraphQL input type."
             )
             # therefore we need to monkey-patch a valid input field
             input_field = GraphQLInputField(GraphQLString)
-            input_field.type = input_field_type
+            input_field.type = type_
         bad_input_object_type = GraphQLInputObjectType(
             "BadInputObject", {"badField": input_field}
         )
@@ -1617,12 +1657,12 @@ def describe_type_system_input_object_fields_must_have_input_types():
 
     @mark.parametrize("type_", input_types, ids=get_name)
     def accepts_an_input_type_as_an_input_field_type(type_):
-        schema = _schema_with_input_field_of_type(type_)
+        schema = _schema_with_input_field(type_)
         assert validate_schema(schema) == []
 
     def rejects_an_empty_input_field_type():
         # noinspection PyTypeChecker
-        schema = _schema_with_input_field_of_type(None)  # type: ignore
+        schema = _schema_with_input_field(None)  # type: ignore
         assert validate_schema(schema) == [
             {
                 "message": "The type of BadInputObject.badField must be Input Type"
@@ -1632,7 +1672,7 @@ def describe_type_system_input_object_fields_must_have_input_types():
 
     @mark.parametrize("type_", not_input_types, ids=get_name)
     def rejects_a_non_input_type_as_an_input_field_type(type_):
-        schema = _schema_with_input_field_of_type(type_)
+        schema = _schema_with_input_field(type_)
         assert validate_schema(schema) == [
             {
                 "message": "The type of BadInputObject.badField must be Input Type"
@@ -1642,7 +1682,7 @@ def describe_type_system_input_object_fields_must_have_input_types():
 
     @mark.parametrize("type_", not_graphql_types, ids=get_name)
     def rejects_a_non_type_value_as_an_input_field_type(type_):
-        schema = _schema_with_input_field_of_type(type_)
+        schema = _schema_with_input_field(type_)
         assert validate_schema(schema) == [
             {
                 "message": "The type of BadInputObject.badField must be Input Type"
@@ -2325,7 +2365,7 @@ def describe_interfaces_must_adhere_to_interface_they_implement():
             "BadInterface", {"field": GraphQLField(GraphQLString)}
         )
         # noinspection PyTypeChecker
-        bad_interface.interfaces.append(some_input_obj)
+        bad_interface.interfaces = (some_input_obj,)
         schema = GraphQLSchema(
             GraphQLObjectType("Query", {"field": GraphQLField(GraphQLString)}),
             types=[bad_interface],
@@ -2631,7 +2671,7 @@ def describe_interfaces_must_adhere_to_interface_they_implement():
 
 
 def describe_assert_valid_schema():
-    def do_not_throw_on_valid_schemas():
+    def does_not_throw_on_valid_schemas():
         schema = build_schema(
             (
                 """
@@ -2643,7 +2683,7 @@ def describe_assert_valid_schema():
         )
         assert_valid_schema(schema)
 
-    def include_multiple_errors_into_a_description():
+    def combines_multiple_errors():
         schema = build_schema("type SomeType")
         with raises(TypeError) as exc_info:
             assert_valid_schema(schema)
