@@ -1,7 +1,8 @@
 from graphql.language import parse, print_ast, Source
-from graphql.pyutils import dedent
 from graphql.utilities import concat_ast
 
+from ..utils import dedent
+
 
 def describe_concat_ast():
     def concatenates_two_asts_together():
