@@ -10,18 +10,52 @@ from graphql.language import (
     visit,
     Visitor,
 )
-from graphql.type import get_named_type, is_composite_type
+from graphql.type import GraphQLSchema, get_named_type, is_composite_type
 from graphql.utilities import TypeInfo, TypeInfoVisitor, build_schema
 
-from ..validation.harness import test_schema
-
-# noinspection PyUnresolvedReferences
 from ..fixtures import kitchen_sink_query  # noqa: F401
 
 
+test_schema = build_schema(
+    """
+    interface Pet {
+      name: String
+    }
+
+    type Dog implements Pet {
+      name: String
+    }
+
+    type Cat implements Pet {
+      name: String
+    }
+
+    type Human {
+      name: String
+      pets: [Pet]
+    }
+
+    type Alien {
+      name(surname: Boolean): String
+    }
+
+    type QueryRoot {
+      human(id: ID): Human
+      alien: Alien
+    }
+
+    schema {
+      query: QueryRoot
+    }
+    """
+)
+
+
 def describe_type_info():
+    schema = GraphQLSchema()
+
     def allow_all_methods_to_be_called_before_entering_any_mode():
-        type_info = TypeInfo(test_schema)
+        type_info = TypeInfo(schema)
 
         assert type_info.get_type() is None
         assert type_info.get_parent_type() is None
@@ -67,6 +101,7 @@ def describe_visit_with_type_info():
 
         class TestVisitor(Visitor):
             def __init__(self):
+                super().__init__()
                 self.root_types = {}
 
             def enter_operation_definition(self, node: OperationDefinitionNode, *_args):
@@ -87,6 +122,7 @@ def describe_visit_with_type_info():
 
         class TestVisitor(Visitor):
             def __init__(self):
+                super().__init__()
                 self.args = []
 
             def enter(self, *args):
@@ -111,9 +147,9 @@ def describe_visit_with_type_info():
 
         ast = parse("{ human(id: 4) { name, pets { ... { name } }, unknown } }")
 
-        # noinspection PyMethodMayBeStatic
         class TestVisitor(Visitor):
-            def enter(self, *args):
+            @staticmethod
+            def enter(*args):
                 parent_type = type_info.get_parent_type()
                 type_ = type_info.get_type()
                 input_type = type_info.get_input_type()
@@ -129,7 +165,8 @@ def describe_visit_with_type_info():
                     )
                 )
 
-            def leave(self, *args):
+            @staticmethod
+            def leave(*args):
                 parent_type = type_info.get_parent_type()
                 type_ = type_info.get_type()
                 input_type = type_info.get_input_type()
@@ -196,9 +233,9 @@ def describe_visit_with_type_info():
 
         ast = parse("{ human(id: 4) { name, pets }, alien }")
 
-        # noinspection PyMethodMayBeStatic
         class TestVisitor(Visitor):
-            def enter(self, *args):
+            @staticmethod
+            def enter(*args):
                 parent_type = type_info.get_parent_type()
                 type_ = type_info.get_type()
                 input_type = type_info.get_input_type()
@@ -230,7 +267,8 @@ def describe_visit_with_type_info():
                         ),
                     )
 
-            def leave(self, *args):
+            @staticmethod
+            def leave(*args):
                 parent_type = type_info.get_parent_type()
                 type_ = type_info.get_type()
                 input_type = type_info.get_input_type()
@@ -305,15 +343,22 @@ def describe_visit_with_type_info():
     def supports_traversal_of_input_values():
         visited = []
 
-        complex_input_type = test_schema.get_type("ComplexInput")
+        schema = build_schema(
+            """
+            input ComplexInput {
+              stringListField: [String]
+            }
+            """
+        )
+        complex_input_type = schema.get_type("ComplexInput")
         assert complex_input_type is not None
-        type_info = TypeInfo(test_schema, None, complex_input_type)
+        type_info = TypeInfo(schema, complex_input_type)
 
         ast = parse_value('{ stringListField: ["foo"] }')
 
-        # noinspection PyMethodMayBeStatic
         class TestVisitor(Visitor):
-            def enter(self, node: Node, *_args):
+            @staticmethod
+            def enter(node: Node, *_args):
                 type_ = type_info.get_input_type()
                 visited.append(
                     (
@@ -324,7 +369,8 @@ def describe_visit_with_type_info():
                     )
                 )
 
-            def leave(self, node: Node, *_args):
+            @staticmethod
+            def leave(node: Node, *_args):
                 type_ = type_info.get_input_type()
                 visited.append(
                     (
@@ -355,15 +401,15 @@ def describe_visit_with_type_info():
 
         human_type = test_schema.get_type("Human")
         assert human_type is not None
-        type_info = TypeInfo(test_schema, None, human_type)
+        type_info = TypeInfo(test_schema, human_type)
 
         ast = parse("{ name, pets { name } }")
         operation_node = ast.definitions[0]
         assert isinstance(operation_node, OperationDefinitionNode)
 
-        # noinspection PyMethodMayBeStatic
         class TestVisitor(Visitor):
-            def enter(self, node: Node, *_args):
+            @staticmethod
+            def enter(node: Node, *_args):
                 parent_type = type_info.get_parent_type()
                 type_ = type_info.get_type()
                 visited.append(
@@ -376,7 +422,8 @@ def describe_visit_with_type_info():
                     )
                 )
 
-            def leave(self, node: Node, *_args):
+            @staticmethod
+            def leave(node: Node, *_args):
                 parent_type = type_info.get_parent_type()
                 type_ = type_info.get_type()
                 visited.append(
